@@ -16,7 +16,7 @@ PYBIND11_MODULE(pyhsd, m) {
     py::class_<Match>(m, "Match")
         .def(py::init<const string &>())
         .def_readwrite("value", &Match::value)
-        .def_readwrite("distance", &Match::value)
+        .def_readwrite("distance", &Match::distance)
         .def("__repr__", [](const Match &a) {
             return "<pyhsd.Match object for '" + a.value + "'>";
         })
